@@ -7,23 +7,15 @@
 
 require 'spec_helper'
 
-class Time
-
-  def to_compact_s
-
-    off = self.utc_offset / 3600
-    off = off >= 0 ? "+#{off}" : off.to_s
-
-    self.strftime('%H%M') + off + self.dup.utc.strftime('(%H%M)')
-  end
-end
-
 
 describe Rufus::Scheduler::CronLine do
 
   def cl(cronline_string)
     Rufus::Scheduler::CronLine.new(cronline_string)
   end
+  def cla(cronline_string)
+    Rufus::Scheduler::CronLine.new(cronline_string).to_a
+  end
 
   def nt(cronline, now)
     Rufus::Scheduler::CronLine.new(cronline).next_time(now)
@@ -56,60 +48,69 @@ describe Rufus::Scheduler::CronLine do
   def no_match(line, time)
     expect(cl(line).matches?(time)).to eq(false)
   end
-  def to_a(line, array)
-    expect(cl(line).to_array).to eq(array)
+
+  def a_eq(line, array)
+    if array.last.is_a?(String) # tz
+      expect(cla(line)).to eq(array)
+    else
+      expect(cla(line)[0..-2]).to eq(array)
+    end
   end
 
   describe '.new' do
 
     it 'interprets cron strings correctly' do
 
-      to_a '* * * * *', [ [0], nil, nil, nil, nil, nil, nil, nil ]
-      to_a '10-12 * * * *', [ [0], [10, 11, 12], nil, nil,  nil, nil, nil, nil ]
-      to_a '* * * * sun,mon', [ [0], nil, nil, nil, nil, [0, 1], nil, nil ]
-      to_a '* * * * mon-wed', [ [0], nil, nil, nil, nil, [1, 2, 3], nil, nil ]
-      to_a '* * * * 7', [ [0], nil, nil, nil, nil, [0], nil, nil ]
-      to_a '* * * * 0', [ [0], nil, nil, nil, nil, [0], nil, nil ]
-      to_a '* * * * 0,1', [ [0], nil, nil, nil, nil, [0,1], nil, nil ]
-      to_a '* * * * 7,1', [ [0], nil, nil, nil, nil, [0,1], nil, nil ]
-      to_a '* * * * 7,0', [ [0], nil, nil, nil, nil, [0], nil, nil ]
-      to_a '* * * * sun,2-4', [ [0], nil, nil, nil, nil, [0, 2, 3, 4], nil, nil ]
+      a_eq '* * * * *', [ [0], nil, nil, nil, nil, nil, nil ]
+      a_eq '10-12 * * * *', [ [0], [10, 11, 12], nil, nil, nil, nil, nil ]
+      a_eq '* * * * sun,mon', [ [0], nil, nil, nil, nil, [0, 1], nil ]
+      a_eq '* * * * mon-wed', [ [0], nil, nil, nil, nil, [1, 2, 3], nil ]
+      a_eq '* * * * 7', [ [0], nil, nil, nil, nil, [0], nil ]
+      a_eq '* * * * 0', [ [0], nil, nil, nil, nil, [0], nil ]
+      a_eq '* * * * 0,1', [ [0], nil, nil, nil, nil, [0,1], nil ]
+      a_eq '* * * * 7,1', [ [0], nil, nil, nil, nil, [0,1], nil ]
+      a_eq '* * * * 7,0', [ [0], nil, nil, nil, nil, [0], nil ]
+      a_eq '* * * * sun,2-4', [ [0], nil, nil, nil, nil, [0, 2, 3, 4], nil ]
 
-      to_a '* * * * sun,mon-tue', [ [0], nil, nil, nil, nil, [0, 1, 2], nil, nil ]
+      a_eq '* * * * sun,mon-tue', [ [0], nil, nil, nil, nil, [0, 1, 2], nil ]
+      a_eq '0 0 * * mon#1,tue', [[0], [0], [0], nil, nil, [2], ["1#1"]]
 
-      to_a '* * * * * *', [ nil, nil, nil, nil, nil, nil, nil, nil ]
-      to_a '1 * * * * *', [ [1], nil, nil, nil, nil, nil, nil, nil ]
-      to_a '7 10-12 * * * *', [ [7], [10, 11, 12], nil, nil, nil, nil, nil, nil ]
-      to_a '1-5 * * * * *', [ [1,2,3,4,5], nil, nil, nil, nil, nil, nil, nil ]
+      a_eq '* * * * * *', [ nil, nil, nil, nil, nil, nil, nil ]
+      a_eq '1 * * * * *', [ [1], nil, nil, nil, nil, nil, nil ]
+      a_eq '7 10-12 * * * *', [ [7], [10, 11, 12], nil, nil, nil, nil, nil ]
+      a_eq '1-5 * * * * *', [ [1,2,3,4,5], nil, nil, nil, nil, nil, nil ]
 
-      to_a '0 0 1 1 *', [ [0], [0], [0], [1], [1], nil, nil, nil ]
+      a_eq '0 0 1 1 *', [ [0], [0], [0], [1], [1], nil, nil ]
 
-      to_a '52 0 * * *', [ [0], [52], [0], nil, nil, nil, nil, nil ]
+      a_eq '52 0 * * *', [ [0], [52], [0], nil, nil, nil, nil ]
+
+      a_eq '0 16 * * *', [ [0], [0], [16], nil, nil, nil, nil ]
+        # as seen on https://github.com/ondrejbartas/sidekiq-cron/issues/128
 
       #if ruby18?
-      #  to_a '0 23-24 * * *', [ [0], [0], [0, 23], nil, nil, nil, nil, nil ]
+      #  a_eq '0 23-24 * * *', [ [0], [0], [0, 23], nil, nil, nil, nil ]
       #else
-      #  to_a '0 23-24 * * *', [ [0], [0], [23, 0], nil, nil, nil, nil, nil ]
+      #  a_eq '0 23-24 * * *', [ [0], [0], [23, 0], nil, nil, nil, nil ]
       #end
         #
         # as reported by Aimee Rose in
         # https://github.com/jmettraux/rufus-scheduler/issues/56
-      to_a '0 23-24 * * *', [ [0], [0], [0, 23], nil, nil, nil, nil, nil ]
+      a_eq '0 23-24 * * *', [ [0], [0], [0, 23], nil, nil, nil, nil ]
 
       #if ruby18?
-      #  to_a '0 23-2 * * *', [ [0], [0], [0, 1, 2, 23], nil, nil, nil, nil, nil ]
+      #  a_eq '0 23-2 * * *', [ [0], [0], [0, 1, 2, 23], nil, nil, nil, nil ]
       #else
-      #  to_a '0 23-2 * * *', [ [0], [0], [23, 0, 1, 2], nil, nil, nil, nil, nil ]
+      #  a_eq '0 23-2 * * *', [ [0], [0], [23, 0, 1, 2], nil, nil, nil, nil ]
       #end
-      to_a '0 23-2 * * *', [ [0], [0], [0, 1, 2, 23], nil, nil, nil, nil, nil ]
+      a_eq '0 23-2 * * *', [ [0], [0], [0, 1, 2, 23], nil, nil, nil, nil ]
 
       # modulo forms work for five-field forms
-      to_a '*/17 * * * *', [[0], [0, 17, 34, 51], nil, nil, nil, nil, nil, nil]
-      to_a '13 */17 * * *', [[0], [13], [0, 17], nil, nil, nil, nil, nil]
+      a_eq '*/17 * * * *', [[0], [0, 17, 34, 51], nil, nil, nil, nil, nil]
+      a_eq '13 */17 * * *', [[0], [13], [0, 17], nil, nil, nil, nil]
 
       # modulo forms work for six-field forms
-      to_a '*/17 * * * * *', [[0, 17, 34, 51], nil, nil, nil, nil, nil, nil, nil]
-      to_a '13 */17 * * * *', [[13], [0, 17, 34, 51], nil, nil, nil, nil, nil, nil]
+      a_eq '*/17 * * * * *', [[0, 17, 34, 51], nil, nil, nil, nil, nil, nil]
+      a_eq '13 */17 * * * *', [[13], [0, 17, 34, 51], nil, nil, nil, nil, nil]
     end
 
     it 'rejects invalid weekday expressions' do
@@ -129,13 +130,13 @@ describe Rufus::Scheduler::CronLine do
 
     it 'interprets cron strings with TZ correctly' do
 
-      to_a('* * * * * EST', [ [0], nil, nil, nil, nil, nil, nil, 'EST' ])
-      to_a('* * * * * * EST', [ nil, nil, nil, nil, nil, nil, nil, 'EST' ])
+      a_eq('* * * * * EST', [ [0], nil, nil, nil, nil, nil, nil, 'EST' ])
+      a_eq('* * * * * * EST', [ nil, nil, nil, nil, nil, nil, nil, 'EST' ])
 
-      to_a(
+      a_eq(
         '* * * * * * America/Chicago',
         [ nil, nil, nil, nil, nil, nil, nil, 'America/Chicago' ])
-      to_a(
+      a_eq(
         '* * * * * * America/New_York',
         [ nil, nil, nil, nil, nil, nil, nil, 'America/New_York' ])
 
@@ -145,22 +146,22 @@ describe Rufus::Scheduler::CronLine do
 
     it 'interprets cron strings with / (slashes) correctly' do
 
-      to_a(
+      a_eq(
         '0 */2 * * *',
-        [ [0], [0], (0..23).select { |e| e.even? }, nil, nil, nil, nil, nil ])
-      to_a(
+        [ [0], [0], (0..23).select { |e| e.even? }, nil, nil, nil, nil ])
+      a_eq(
         '0 0-23/2 * * *',
-        [ [0], [0], (0..23).select { |e| e.even? }, nil, nil, nil, nil, nil ])
-      to_a(
+        [ [0], [0], (0..23).select { |e| e.even? }, nil, nil, nil, nil ])
+      a_eq(
         '0 7-23/2 * * *',
-        [ [0], [0], (7..23).select { |e| e.odd? }, nil, nil, nil, nil, nil ])
-      to_a(
+        [ [0], [0], (7..23).select { |e| e.odd? }, nil, nil, nil, nil ])
+      a_eq(
         '*/10 * * * *',
-        [ [0], [0, 10, 20, 30, 40, 50], nil, nil, nil, nil, nil, nil ])
+        [ [0], [0, 10, 20, 30, 40, 50], nil, nil, nil, nil, nil ])
 
       # fighting https://github.com/jmettraux/rufus-scheduler/issues/65
       #
-      to_a(
+      a_eq(
         '*/10 * * * * Europe/Berlin',
         [ [0], [ 0, 10, 20, 30, 40, 50], nil, nil, nil, nil, nil, 'Europe/Berlin' ])
     end
@@ -169,9 +170,9 @@ describe Rufus::Scheduler::CronLine do
 
       # fighting https://github.com/jmettraux/rufus-scheduler/issues/65
 
-      to_a(
+      a_eq(
         '/10 * * * *',
-        [ [0], [ 0, 10, 20, 30, 40, 50], nil, nil, nil, nil, nil, nil ])
+        [ [0], [ 0, 10, 20, 30, 40, 50], nil, nil, nil, nil, nil, ])
     end
 
     it 'rejects / for days (every other wednesday)' do
@@ -190,98 +191,153 @@ describe Rufus::Scheduler::CronLine do
 
     it 'accepts items with initial 0' do
 
-      to_a(
-        '09 * * * *', [ [0], [9], nil, nil, nil, nil, nil, nil ])
-      to_a(
-        '09-12 * * * *', [ [0], [9, 10, 11, 12], nil, nil, nil, nil, nil, nil ])
-      to_a(
-        '07-08 * * * *', [ [0], [7, 8], nil, nil, nil, nil, nil, nil ])
-      to_a(
-        '* */08 * * *', [ [0], nil, [0, 8, 16], nil, nil, nil, nil, nil ])
-      to_a(
-        '* */07 * * *', [ [0], nil, [0, 7, 14, 21], nil, nil, nil, nil, nil ])
-      to_a(
-        '* 01-09/04 * * *', [ [0], nil, [1, 5, 9], nil, nil, nil, nil, nil ])
-      to_a(
-        '* * * * 06', [ [0], nil, nil, nil, nil, [6], nil, nil ])
+      a_eq('09 * * * *', [ [0], [9], nil, nil, nil, nil, nil ])
+      a_eq('09-12 * * * *', [ [0], [9, 10, 11, 12], nil, nil, nil, nil, nil ])
+      a_eq('07-08 * * * *', [ [0], [7, 8], nil, nil, nil, nil, nil ])
+      a_eq('* */08 * * *', [ [0], nil, [0, 8, 16], nil, nil, nil, nil ])
+      a_eq('* */07 * * *', [ [0], nil, [0, 7, 14, 21], nil, nil, nil, nil ])
+      a_eq('* 01-09/04 * * *', [ [0], nil, [1, 5, 9], nil, nil, nil, nil ])
+      a_eq('* * * * 06', [ [0], nil, nil, nil, nil, [6], nil, ])
     end
 
     it 'interprets cron strings with L correctly' do
 
-      to_a(
-        '* * L * *', [[0], nil, nil, ['L'], nil, nil, nil, nil ])
-      to_a(
-        '* * 2-5,L * *', [[0], nil, nil, [2,3,4,5,'L'], nil, nil, nil, nil ])
-      to_a(
-        '* * */8,L * *', [[0], nil, nil, [1,9,17,25,'L'], nil, nil, nil, nil ])
+      a_eq('* * L * *', [[0], nil, nil, ['L'], nil, nil, nil ])
+      a_eq('* * 2-5,L * *', [[0], nil, nil, [2,3,4,5,'L'], nil, nil, nil ])
+      a_eq('* * */8,L * *', [[0], nil, nil, [1,9,17,25,'L'], nil, nil, nil ])
+    end
+
+    # issue https://github.com/jmettraux/rufus-scheduler/issues/202
+    it 'rejects zero increments' do
+
+      expect {
+        Rufus::Scheduler::CronLine.new('*/0 * * * *')
+      }.to raise_error(
+        ArgumentError, '"*/0" increment must be greater than zero'
+      )
+
+      expect {
+        Rufus::Scheduler::CronLine.new('* */0 * * *')
+      }.to raise_error(
+        ArgumentError, '"*/0" increment must be greater than zero'
+      )
     end
 
     it 'does not support ranges for L' do
 
-      expect { cl '* * 15-L * *'}.to raise_error(ArgumentError)
-      expect { cl '* * L/4 * *'}.to raise_error(ArgumentError)
+      expect { cl '* * 15-L * *' }.to raise_error(
+        ArgumentError, 'cannot parse "15-L"')
+      expect { cl '* * L/4 * *' }.to raise_error(
+        ArgumentError, 'cannot parse "L/4"')
     end
 
     it 'does not support multiple Ls' do
 
-      expect { cl '* * L,L * *'}.to raise_error(ArgumentError)
+      expect { cl '* * L,L * *' }.to raise_error(
+        ArgumentError, 'found duplicates in "L,L"')
     end
 
     it 'raises if L is used for something else than days' do
 
-      expect { cl '* L * * *'}.to raise_error(ArgumentError)
+      expect { cl '* L * * *' }.to raise_error(
+        ArgumentError, "invalid cronline: '* L * * *'")
     end
 
-    it 'raises for out of range input' do
+    it 'accepts L for day-of-week' do
 
-      expect { cl '60-62 * * * *'}.to raise_error(ArgumentError)
-      expect { cl '62 * * * *'}.to raise_error(ArgumentError)
-      expect { cl '60 * * * *'}.to raise_error(ArgumentError)
-      expect { cl '* 25-26 * * *'}.to raise_error(ArgumentError)
-      expect { cl '* 25 * * *'}.to raise_error(ArgumentError)
-        #
-        # as reported by Aimee Rose in
-        # https://github.com/jmettraux/rufus-scheduler/pull/58
+      a_eq '* * * * 5L', [ [ 0 ], nil, nil, nil, nil, nil, [ '5#-1' ] ]
+      a_eq '* * * * FRIL', [ [ 0 ], nil, nil, nil, nil, nil, [ '5#-1' ] ]
+    end
+
+    it 'accepts negative days' do
+
+      a_eq('* * 8,-8 * *', [[0], nil, nil, [-8,8], nil, nil, nil ])
+    end
+
+    it 'accepts negative day ranges' do
+
+      a_eq('* * -10--8 * *', [[0], nil, nil, [-10,-9,-8], nil, nil, nil ])
+    end
+
+    it 'rejects day descending ranges' do
+
+      expect { cl('* * 10-8 * *') }.to raise_error(
+        ArgumentError, '"10-8" descending day ranges not allowed')
+      expect { cl('* * -8--10 * *') }.to raise_error(
+        ArgumentError, '"-8--10" descending day ranges not allowed')
+    end
+
+    it 'rejects negative/positive day ranges' do
+
+      expect { cl('* * 8--2 * *') }.to raise_error(
+        ArgumentError, '"8--2" positive/negative ranges not allowed')
+      expect { cl('* * -2-8 * *') }.to raise_error(
+        ArgumentError, '"-2-8" positive/negative ranges not allowed')
+    end
+
+    it 'rejects out of range input' do
+
+      expect { cl '60-62 * * * *' }.to raise_error(
+        ArgumentError, '"60-62" is not in range 0..59')
+      expect { cl '62 * * * *' }.to raise_error(
+        ArgumentError, '"62" is not in range 0..59')
+      expect { cl '60 * * * *' }.to raise_error(
+        ArgumentError, '"60" is not in range 0..59')
+      expect { cl '* 25-26 * * *' }.to raise_error(
+        ArgumentError, '"25-26" is not in range 0..24')
+      expect { cl '* 25 * * *' }.to raise_error(
+        ArgumentError, '"25" is not in range 0..24')
+          #
+          # as reported by Aimee Rose in
+          # https://github.com/jmettraux/rufus-scheduler/pull/58
+    end
+
+    it 'rejects day 0' do
+
+      expect { cl '0 0 0 * *' }.to raise_error(
+        ArgumentError, 'invalid day 0 in cronline')
+      expect { cl '* * 0 * *' }.to raise_error(
+        ArgumentError, 'invalid day 0 in cronline')
+      expect { cl '* * * 0 * *' }.to raise_error(
+        ArgumentError, 'invalid day 0 in cronline')
+          #
+          # as reported by Ramon Tayag in
+          # https://github.com/jmettraux/rufus-scheduler/issues/221
     end
 
     it 'sorts seconds' do
 
-      to_a(
-        '23,30,10 * * * * *', [ [10,23,30], nil, nil, nil, nil, nil, nil, nil ])
+      a_eq('23,30,10 * * * * *', [ [10,23,30], nil, nil, nil, nil, nil, nil ])
     end
 
     it 'sorts minutes' do
 
-      to_a(
-        '23,30,10 * * * * ', [ [0], [10,23,30], nil, nil, nil, nil, nil, nil ])
+      a_eq('23,30,10 * * * * ', [ [0], [10,23,30], nil, nil, nil, nil, nil ])
     end
 
     it 'sorts days' do
 
-      to_a(
-        '* * 14,7 * * ', [ [0], nil, nil, [7, 14], nil, nil, nil, nil ])
+      a_eq('* * 14,7 * * ', [ [0], nil, nil, [7, 14], nil, nil, nil ])
     end
 
     it 'sorts months' do
 
-      to_a(
-        '* * * 11,3,4 * ', [ [0], nil, nil, nil, [3,4,11], nil, nil, nil ])
+      a_eq('* * * 11,3,4 * ', [ [0], nil, nil, nil, [3,4,11], nil, nil ])
     end
 
     it 'sorts days of week' do
 
-      to_a(
-        '* * * * Sun,Fri,2 ', [ [0], nil, nil, nil, nil, [0, 2, 5], nil, nil ])
+      a_eq('* * * * Sun,Fri,2 ', [ [0], nil, nil, nil, nil, [0,2,5], nil ])
     end
   end
 
   describe '#next_time' do
 
-    it 'computes the next occurence correctly' do
+    it 'computes the next occurrence correctly' do
 
       in_zone 'Europe/Berlin' do
 
-        now = Time.at(0) - 3600
+        now = EtOrbi::EoTime.new(-3600, nil)
 
         expect(nt('* * * * *', now)).to eq(now + 60)
         expect(nt('* * * * sun', now)).to eq(now + 259200)
@@ -301,81 +357,93 @@ describe Rufus::Scheduler::CronLine do
         expect(nt('0 0 * * *', now)).to eq(now + 24 * 3600)
         expect(nt('0 24 * * *', now)).to eq(now + 24 * 3600)
 
-        now = local(2008, 12, 31, 23, 59, 59, 0)
+        now = EtOrbi::EoTime.new(local(2008, 12, 31, 23, 59, 59, 0), nil)
 
         expect(nt('* * * * *', now)).to eq(now + 1)
       end
     end
 
-    it 'computes the next occurence correctly in local TZ (TZ not specified)' do
+    it 'computes the next occurrence correctly in local TZ (TZ not specified)' do
 
       now = local(1970, 1, 1)
 
-      expect(nt('* * * * *', now)).to eq(local(1970, 1, 1, 0, 1))
-      expect(nt('* * * * sun', now)).to eq(local(1970, 1, 4))
-      expect(nt('* * * * * *', now)).to eq(local(1970, 1, 1, 0, 0, 1))
-      expect(nt('* * 13 * fri', now)).to eq(local(1970, 2, 13))
+      expect(nt('* * * * *', now)).to eq(zlocal(1970, 1, 1, 0, 1))
+      expect(nt('* * * * sun', now)).to eq(zlocal(1970, 1, 4))
+      expect(nt('* * * * * *', now)).to eq(zlocal(1970, 1, 1, 0, 0, 1))
+      expect(nt('* * 13 * fri', now)).to eq(zlocal(1970, 2, 13))
 
-      expect(nt('10 12 13 12 *', now)).to eq(local(1970, 12, 13, 12, 10))
+      expect(nt('10 12 13 12 *', now)).to eq(zlocal(1970, 12, 13, 12, 10))
         # this one is slow (1 year == 3 seconds)
-      expect(nt('* * 1 6 *', now)).to eq(local(1970, 6, 1))
+      expect(nt('* * 1 6 *', now)).to eq(zlocal(1970, 6, 1))
 
-      expect(nt('0 0 * * thu', now)).to eq(local(1970, 1, 8))
+      expect(nt('0 0 * * thu', now)).to eq(zlocal(1970, 1, 8))
     end
 
-    it 'computes the next occurence correctly in UTC (TZ specified)' do
+    it 'computes the next occurrence correctly in UTC (TZ specified)' do
 
-      zone = 'Europe/Stockholm'
-      now = in_zone(zone) { Time.local(1970, 1, 1) }
+      z = 'Europe/Stockholm'
+      now = EtOrbi::EoTime.parse("1970-1-1 00:00:00 #{z}")
 
-      expect(nt("* * * * * #{zone}", now)).to eq(utc(1969, 12, 31, 23, 1))
-      expect(nt("* * * * sun #{zone}", now)).to eq(utc(1970, 1, 3, 23))
-      expect(nt("* * * * * * #{zone}", now)).to eq(utc(1969, 12, 31, 23, 0, 1))
-      expect(nt("* * 13 * fri #{zone}", now)).to eq(utc(1970, 2, 12, 23))
+      expect(nt("* * * * * #{z}", now)).to eq(ztu(z, 1969, 12, 31, 23, 1))
+      expect(nt("* * * * sun #{z}", now)).to eq(ztu(z, 1970, 1, 3, 23))
+      expect(nt("* * * * * * #{z}", now)).to eq(ztu(z, 1969, 12, 31, 23, 0, 1))
+      expect(nt("* * 13 * fri #{z}", now)).to eq(ztu(z, 1970, 2, 12, 23))
 
-      expect(nt("10 12 13 12 * #{zone}", now)).to eq(utc(1970, 12, 13, 11, 10))
-      expect(nt("* * 1 6 * #{zone}", now)).to eq(utc(1970, 5, 31, 23))
+      expect(nt("10 12 13 12 * #{z}", now)).to eq(ztu(z, 1970, 12, 13, 11, 10))
+      expect(nt("* * 1 6 * #{z}", now)).to eq(ztu(z, 1970, 5, 31, 23))
 
-      expect(nt("0 0 * * thu #{zone}", now)).to eq(utc(1970, 1, 7, 23))
+      expect(nt("0 0 * * thu #{z}", now)).to eq(ztu(z, 1970, 1, 7, 23))
     end
 
     it 'computes the next time correctly when there is a sun#2 involved' do
 
-      expect(nt('* * * * sun#1', local(1970, 1, 1))).to eq(local(1970, 1, 4))
-      expect(nt('* * * * sun#2', local(1970, 1, 1))).to eq(local(1970, 1, 11))
+      expect(nt('* * * * sun#1', zlocal(1970, 1, 1))).to eq(zlocal(1970, 1, 4))
+      expect(nt('* * * * sun#2', zlocal(1970, 1, 1))).to eq(zlocal(1970, 1, 11))
 
-      expect(nt('* * * * sun#2', local(1970, 1, 12))).to eq(local(1970, 2, 8))
+      expect(nt('* * * * sun#2', zlocal(1970, 1, 12))).to eq(zlocal(1970, 2, 8))
     end
 
     it 'computes next time correctly when there is a sun#2,sun#3 involved' do
 
       expect(
-        nt('* * * * sun#2,sun#3', local(1970, 1, 1))).to eq(local(1970, 1, 11))
+        nt('* * * * sun#2,sun#3', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 11))
       expect(
-        nt('* * * * sun#2,sun#3', local(1970, 1, 12))).to eq(local(1970, 1, 18))
+        nt('* * * * sun#2,sun#3', zlo(1970, 1, 12))).to eq(zlo(1970, 1, 18))
     end
 
-    it 'understands sun#L' do
+    it 'computes next time correctly when weekdays is combined with monthdays' do
 
-      expect(nt('* * * * sun#L', local(1970, 1, 1))).to eq(local(1970, 1, 25))
+      expect(
+        nt('* * * * mon#2,tue', zlo(2016, 12, 1))).to eq(zlo(2016, 12, 6))
+      expect(
+        nt('* * * * mon#2,tue', zlo(2016, 12, 7))).to eq(zlo(2016, 12, 12))
     end
 
-    it 'understands sun#-1' do
+    it 'understands sun#L and co' do
 
-      expect(nt('* * * * sun#-1', local(1970, 1, 1))).to eq(local(1970, 1, 25))
+      expect(nt('* * * * sunL', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 25))
+      expect(nt('* * * * sun#L', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 25))
+      expect(nt('* * * * sun#-1', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 25))
+    end
+
+    it 'understands 0#L and co' do
+
+      expect(nt('* * * * 0L', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 25))
+      expect(nt('* * * * 0#L', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 25))
+      expect(nt('* * * * 0#-1', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 25))
     end
 
     it 'understands sun#-2' do
 
-      expect(nt('* * * * sun#-2', local(1970, 1, 1))).to eq(local(1970, 1, 18))
+      expect(nt('* * * * sun#-2', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 18))
     end
 
     it 'computes the next time correctly when "L" (last day of month)' do
 
-      expect(nt('* * L * *', lo(1970, 1, 1))).to eq(lo(1970, 1, 31))
-      expect(nt('* * L * *', lo(1970, 2, 1))).to eq(lo(1970, 2, 28))
-      expect(nt('* * L * *', lo(1972, 2, 1))).to eq(lo(1972, 2, 29))
-      expect(nt('* * L * *', lo(1970, 4, 1))).to eq(lo(1970, 4, 30))
+      expect(nt('* * L * *', zlo(1970, 1, 1))).to eq(zlo(1970, 1, 31))
+      expect(nt('* * L * *', zlo(1970, 2, 1))).to eq(zlo(1970, 2, 28))
+      expect(nt('* * L * *', zlo(1972, 2, 1))).to eq(zlo(1972, 2, 29))
+      expect(nt('* * L * *', zlo(1970, 4, 1))).to eq(zlo(1970, 4, 30))
     end
 
     it 'returns a time with subseconds chopped off' do
@@ -427,31 +495,39 @@ describe Rufus::Scheduler::CronLine do
 
     it 'understands six-field crontabs' do
 
-      expect(nt('* * * * * *',local(1970,1,1,1,1,1))).to(
-        eq(local(1970,1,1,1,1,2))
+      expect(nt('* * * * * *', zlocal(1970, 1, 1, 1, 1, 1))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 2))
       )
-      expect(nt('* * * * * *',local(1970,1,1,1,1,2))).to(
-        eq(local(1970,1,1,1,1,3))
+      expect(nt('* * * * * *', zlocal(1970, 1, 1, 1, 1, 2))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 3))
       )
-      expect(nt('*/10 * * * * *',local(1970,1,1,1,1,0))).to(
-        eq(local(1970,1,1,1,1,10))
+      expect(nt('*/10 * * * * *', zlocal(1970, 1, 1, 1, 1, 0))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 10))
       )
-      expect(nt('*/10 * * * * *',local(1970,1,1,1,1,9))).to(
-        eq(local(1970,1,1,1,1,10))
+      expect(nt('*/10 * * * * *', zlocal(1970, 1, 1, 1, 1, 9))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 10))
       )
-      expect(nt('*/10 * * * * *',local(1970,1,1,1,1,10))).to(
-        eq(local(1970,1,1,1,1,20))
+      expect(nt('*/10 * * * * *', zlocal(1970, 1, 1, 1, 1, 10))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 20))
       )
-      expect(nt('*/10 * * * * *',local(1970,1,1,1,1,40))).to(
-        eq(local(1970,1,1,1,1,50))
+      expect(nt('*/10 * * * * *', zlocal(1970, 1, 1, 1, 1, 40))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 50))
       )
-      expect(nt('*/10 * * * * *',local(1970,1,1,1,1,49))).to(
-        eq(local(1970,1,1,1,1,50))
+      expect(nt('*/10 * * * * *', zlocal(1970, 1, 1, 1, 1, 49))).to(
+        eq(zlocal(1970, 1, 1, 1, 1, 50))
       )
-      expect(nt('*/10 * * * * *',local(1970,1,1,1,1,50))).to(
-        eq(local(1970,1,1,1,2,00))
+      expect(nt('*/10 * * * * *', zlocal(1970, 1, 1, 1, 1, 50))).to(
+        eq(zlocal(1970, 1, 1, 1, 2, 00))
       )
     end
+
+    it "raises a RangeError if it doesn't reach the next time within x years" do
+
+      cronline = cl('0 0 * * mon#2,tue')
+      class << cronline; def date_match?(x=nil); false; end; end
+
+      expect { cronline.next_time }.to raise_error(RangeError)
+    end
   end
 
   describe '#next_second' do
@@ -499,38 +575,38 @@ describe Rufus::Scheduler::CronLine do
 
     it 'returns the previous time the cron should have triggered' do
 
-      expect(
-        pt('* * * * sun', lo(1970, 1, 1))).to eq(lo(1969, 12, 28, 23, 59, 00))
-      expect(
-        pt('* * 13 * *', lo(1970, 1, 1))).to eq(lo(1969, 12, 13, 23, 59, 00))
-      expect(
-        pt('0 12 13 * *', lo(1970, 1, 1))).to eq(lo(1969, 12, 13, 12, 00))
-      expect(
-        pt('0 0 2 1 *', lo(1970, 1, 1))).to eq(lo(1969, 1, 2, 0, 00))
+      expect(pt('* * * * sun', zlo(1970, 1, 1))
+        ).to eq(zlo(1969, 12, 28, 23, 59, 00))
+      expect(pt('* * 13 * *', zlo(1970, 1, 1))
+        ).to eq(zlo(1969, 12, 13, 23, 59, 00))
+      expect(pt('0 12 13 * *', zlo(1970, 1, 1))
+        ).to eq(zlo(1969, 12, 13, 12, 00))
+      expect(pt('0 0 2 1 *', zlo(1970, 1, 1))
+        ).to eq(zlo(1969, 1, 2, 0, 00))
 
-      expect(
-        pt('* * * * * sun', lo(1970, 1, 1))).to eq(lo(1969, 12, 28, 23, 59, 59))
+      expect(pt('* * * * * sun', zlo(1970, 1, 1))
+        ).to eq(zlo(1969, 12, 28, 23, 59, 59))
     end
 
     it 'jumps to the previous minute if necessary (gh-177)' do
 
       t = local(1970, 12, 31, 1, 1, 0) # vanilla
-      expect(pt('43,44 * * * * *', t)).to eq(lo(1970, 12, 31, 1, 0, 44))
+      expect(pt('43,44 * * * * *', t)).to eq(zlo(1970, 12, 31, 1, 0, 44))
 
       t = local(1970, 12, 31, 1, 1, 30) # 30 < 43 <---- here!
-      expect(pt('43,44 * * * * *', t)).to eq(lo(1970, 12, 31, 1, 0, 44))
+      expect(pt('43,44 * * * * *', t)).to eq(zlo(1970, 12, 31, 1, 0, 44))
 
       t = local(1970, 12, 31, 1, 1, 43) # 43 <= 43 < 44
-      expect(pt('43,44 * * * * *', t)).to eq(lo(1970, 12, 31, 1, 0, 44))
+      expect(pt('43,44 * * * * *', t)).to eq(zlo(1970, 12, 31, 1, 0, 44))
 
       t = local(1970, 12, 31, 1, 1, 44) # 44 <= 44
-      expect(pt('43,44 * * * * *', t)).to eq(lo(1970, 12, 31, 1, 1, 43))
+      expect(pt('43,44 * * * * *', t)).to eq(zlo(1970, 12, 31, 1, 1, 43))
 
       t = local(1970, 12, 31, 1, 1, 59) # 44 < 59
-      expect(pt('43,44 * * * * *', t)).to eq(lo(1970, 12, 31, 1, 1, 44))
+      expect(pt('43,44 * * * * *', t)).to eq(zlo(1970, 12, 31, 1, 1, 44))
 
       t = local(1970, 12, 31, 1, 1, 30) # a bigger jump
-      expect(pt('43,44 10 * * * *', t)).to eq(lo(1970, 12, 31, 0, 10, 44))
+      expect(pt('43,44 10 * * * *', t)).to eq(zlo(1970, 12, 31, 0, 10, 44))
     end
 
     # New York      EST: UTC-5
@@ -576,14 +652,22 @@ describe Rufus::Scheduler::CronLine do
 
       expect(
         pt('* 0,10,20 * * *', lo(2000, 1, 1))).to eq(
-          lo(1999, 12, 31, 20, 59, 00))
+          zlo(1999, 12, 31, 20, 59, 00))
     end
 
     it 'computes correctly when * */10' do
 
       expect(
         pt('* */10 * * *', lo(2000, 1, 1))).to eq(
-          lo(1999, 12, 31, 20, 59, 00))
+          zlo(1999, 12, 31, 20, 59, 00))
+    end
+
+    it "raises a RangeError if it doesn't reach the previous time within x years" do
+
+      cronline = cl('0 0 * * mon#2,tue')
+      class << cronline; def date_match?(x=nil); false; end; end
+
+      expect { cronline.previous_time }.to raise_error(RangeError)
     end
   end
 
@@ -648,6 +732,26 @@ describe Rufus::Scheduler::CronLine do
       no_match '* * L * *', utc(1970, 1, 30)
     end
 
+    it 'matches negative days' do
+
+      no_match '* * -2 * *', utc(1970, 1, 28)
+      match '* * -2 * *', utc(1970, 1, 29)
+      no_match '* * -2 * *', utc(1970, 1, 30)
+    end
+
+    it 'matches negative day ranges' do
+
+      match '* * -5--3 * *', utc(1970, 1, 27)
+      match '* * -5--3 * *', utc(1970, 1, 28)
+
+      match '* * -10--5/2 * *', utc(1970, 1, 21)
+      match '* * -10--5/2 * *', utc(1970, 1, 23)
+      match '* * -10--5/2 * *', utc(1970, 1, 25)
+      no_match '* * -10--5/2 * *', utc(1970, 1, 22)
+      no_match '* * -10--5/2 * *', utc(1970, 1, 24)
+      no_match '* * -10--5/2 * *', utc(1970, 1, 26)
+    end
+
     it 'matches correctly when there is a sun#2,sun#3 involved' do
 
       no_match '* * * * sun#2,sun#3', local(1970, 1, 4)
@@ -674,32 +778,12 @@ describe Rufus::Scheduler::CronLine do
     end
   end
 
-  describe '#monthdays' do
-
-    it 'returns the appropriate "sun#2"-like string' do
-
-      class Rufus::Scheduler::CronLine
-        public :monthdays
-      end
-
-      cl = Rufus::Scheduler::CronLine.new('* * * * *')
-
-      expect(cl.monthdays(local(1970, 1, 1))).to eq(%w[ thu#1 thu#-5 ])
-      expect(cl.monthdays(local(1970, 1, 7))).to eq(%w[ wed#1 wed#-4 ])
-      expect(cl.monthdays(local(1970, 1, 14))).to eq(%w[ wed#2 wed#-3 ])
-
-      expect(cl.monthdays(local(2011, 3, 11))).to eq(%w[ fri#2 fri#-3 ])
-    end
-  end
-
   describe '#frequency' do
 
-    it 'returns the shortest delta between two occurrences' do
+    it 'returns the shortest delta between two occurrences (5 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '* * * * *').frequency).to eq(60)
-      expect(Rufus::Scheduler::CronLine.new(
-        '* * * * * *').frequency).to eq(1)
 
       expect(Rufus::Scheduler::CronLine.new(
         '5 23 * * *').frequency).to eq(24 * 3600)
@@ -707,12 +791,18 @@ describe Rufus::Scheduler::CronLine do
         '5 * * * *').frequency).to eq(3600)
       expect(Rufus::Scheduler::CronLine.new(
         '10,20,30 * * * *').frequency).to eq(600)
+    end
+
+    it 'returns the shortest delta between two occurrences (6 fields)' do
+
+      expect(Rufus::Scheduler::CronLine.new(
+        '* * * * * *').frequency).to eq(1)
 
       expect(Rufus::Scheduler::CronLine.new(
         '10,20,30 * * * * *').frequency).to eq(10)
     end
 
-    it 'spots B-A vs C-B asymmetry in five-field forms' do
+    it 'spots B-A vs C-B asymmetry (5 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '10,17,30 * * * *').frequency).to eq(7 * 60)
@@ -722,7 +812,7 @@ describe Rufus::Scheduler::CronLine do
         '23,10,30 * * * *').frequency).to eq(7 * 60)
     end
 
-    it 'spots B-A vs C-B asymmetry in six-field forms' do
+    it 'spots B-A vs C-B asymmetry (6 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '10,17,30 * * * * *').frequency).to eq(7)
@@ -732,7 +822,7 @@ describe Rufus::Scheduler::CronLine do
         '23,10,30 * * * * *').frequency).to eq(7)
     end
 
-    it 'handles crontab steps syntax in five-field forms' do
+    it 'handles crontab steps syntax (5 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '*/10 * * * *').frequency).to eq(10 * 60)
@@ -742,7 +832,7 @@ describe Rufus::Scheduler::CronLine do
         '0 */10 * * *').frequency).to eq(4 * 60 * 60) # 2000 to 0000
     end
 
-    it 'handles crontab steps syntax in six-field forms' do
+    it 'handles crontab steps syntax (6 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '*/10 * * * * *').frequency).to eq(10)
@@ -755,12 +845,10 @@ describe Rufus::Scheduler::CronLine do
 
   describe '#brute_frequency' do
 
-    it 'returns the shortest delta between two occurrences' do
+    it 'returns the shortest delta between two occurrences (5 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '* * * * *').brute_frequency).to eq(60)
-      expect(Rufus::Scheduler::CronLine.new(
-        '* * * * * *').brute_frequency).to eq(1)
 
       expect(Rufus::Scheduler::CronLine.new(
         '5 23 * * *').brute_frequency).to eq(24 * 3600)
@@ -768,11 +856,25 @@ describe Rufus::Scheduler::CronLine do
         '5 * * * *').brute_frequency).to eq(3600)
       expect(Rufus::Scheduler::CronLine.new(
         '10,20,30 * * * *').brute_frequency).to eq(600)
+      expect(Rufus::Scheduler::CronLine.new(
+        '* 1 * * sun#2,sun#3').brute_frequency).to eq(60)
+      expect(Rufus::Scheduler::CronLine.new(
+        '0 0,12 1 */2 *').brute_frequency).to eq(43200)
+      expect(Rufus::Scheduler::CronLine.new(
+        '* * * * mon#2,tue').brute_frequency).to eq(60)
+      expect(Rufus::Scheduler::CronLine.new(
+        '0 4 15-21 * *').brute_frequency).to eq(86400)
+      expect(Rufus::Scheduler::CronLine.new(
+        '1,2 * * * * 1-5').brute_frequency).to eq(1)
+    end
 
-      #Rufus::Scheduler::CronLine.new(
-      #    '10,20,30 * * * * *').brute_frequency.should == 10
-        #
-        # takes > 20s ...
+    it 'returns the shortest delta between two occurrences (6 fields)' do
+
+      expect(Rufus::Scheduler::CronLine.new(
+        '* * * * * *').brute_frequency).to eq(1)
+
+      expect(Rufus::Scheduler::CronLine.new(
+        '10,20,30 * * * * *').brute_frequency).to eq(10)
     end
 
     # some combos only appear every other year...
@@ -783,7 +885,7 @@ describe Rufus::Scheduler::CronLine do
         '1 2 3 4 5').brute_frequency).to eq(31622400)
     end
 
-    it 'spots B-A vs C-B asymmetry in five-field forms' do
+    it 'spots B-A vs C-B asymmetry (5 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '10,17,30 * * * *').brute_frequency).to eq(7 * 60)
@@ -791,7 +893,7 @@ describe Rufus::Scheduler::CronLine do
         '10,23,30 * * * *').brute_frequency).to eq(7 * 60)
     end
 
-    it 'spots B-A vs C-B asymmetry in six-field forms' do
+    it 'spots B-A vs C-B asymmetry (6 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '10,17,30 * * * * *').brute_frequency).to eq(7)
@@ -799,7 +901,7 @@ describe Rufus::Scheduler::CronLine do
         '10,23,30 * * * * *').brute_frequency).to eq(7)
     end
 
-    it 'handles crontab modulo syntax in five-field forms' do
+    it 'handles crontab modulo syntax (5 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '*/10 * * * *').brute_frequency).to eq(10 * 60)
@@ -809,7 +911,7 @@ describe Rufus::Scheduler::CronLine do
         '0 */10 * * *').brute_frequency).to eq(4 * 60 * 60) # 2000 to 0000
     end
 
-    it 'handles crontab modulo syntax in six-field forms' do
+    it 'handles crontab modulo syntax (6 fields)' do
 
       expect(Rufus::Scheduler::CronLine.new(
         '*/10 * * * * *').brute_frequency).to eq(10)
@@ -854,16 +956,16 @@ describe Rufus::Scheduler::CronLine do
         n0 = cl0.next_time(friday)
         n1 = cl1.next_time(friday)
 
-        expect(n0.strftime('%H:%M:%S %^a')).to eq('00:02:00 TUE')
-        expect(n1.strftime('%H:%M:%S %^a')).to eq('08:45:00 MON')
+        expect(n0.strftime('%H:%M:%S %a')).to eq('00:02:00 Tue')
+        expect(n1.strftime('%H:%M:%S %a')).to eq('08:45:00 Mon')
 
         expect(n0.isdst).to eq(true)
         expect(n1.isdst).to eq(true)
 
         expect(
-          (n0 - 24 * 3600 * 3).strftime('%H:%M:%S %^a')).to eq('23:02:00 FRI')
+          (n0 - 24 * 3600 * 3).strftime('%H:%M:%S %a')).to eq('23:02:00 Fri')
         expect(
-          (n1 - 24 * 3600 * 3).strftime('%H:%M:%S %^a')).to eq('07:45:00 FRI')
+          (n1 - 24 * 3600 * 3).strftime('%H:%M:%S %a')).to eq('07:45:00 Fri')
       end
     end
 
@@ -895,24 +997,27 @@ describe Rufus::Scheduler::CronLine do
         n0 = cl0.next_time(friday)
         n1 = cl1.next_time(friday)
 
-        expect(n0.strftime('%H:%M:%S %^a')).to eq('00:02:00 MON')
-        expect(n1.strftime('%H:%M:%S %^a')).to eq('08:45:00 MON')
+        expect(n0.strftime('%H:%M:%S %a')).to eq('00:02:00 Mon')
+        expect(n1.strftime('%H:%M:%S %a')).to eq('08:45:00 Mon')
 
         expect(n0.isdst).to eq(false)
         expect(n1.isdst).to eq(false)
 
         expect(
-          (n0 - 24 * 3600 * 3).strftime('%H:%M:%S %^a')).to eq('01:02:00 FRI')
+          (n0 - 24 * 3600 * 3).strftime('%H:%M:%S %a')).to eq('01:02:00 Fri')
         expect(
-          (n1 - 24 * 3600 * 3).strftime('%H:%M:%S %^a')).to eq('09:45:00 FRI')
+          (n1 - 24 * 3600 * 3).strftime('%H:%M:%S %a')).to eq('09:45:00 Fri')
       end
     end
 
     it 'correctly increments through a DST transition' do
 
       expect(
-        nt('* * * * * America/Los_Angeles', Time.utc(2015, 3, 8, 9, 59))
-      ).to eq(Time.utc(2015, 3, 8, 10, 00))
+        nt('* * * * * America/Los_Angeles', Time.utc(2015, 3, 8, 9, 59)) \
+          .strftime('%Y-%m-%d %H:%M:%S %Z %z')
+      ).to eq(
+        '2015-03-08 03:00:00 PDT -0700'
+      )
     end
 
     it 'correctly increments every minute through a DST transition' do
@@ -926,7 +1031,7 @@ describe Rufus::Scheduler::CronLine do
         points =
           4.times.collect do
             t = line.next_time(t)
-            t.to_compact_s
+            t.to_utc_comparison_s
           end
 
         expect(points).to eq([
@@ -941,8 +1046,11 @@ describe Rufus::Scheduler::CronLine do
     it 'correctly decrements through a DST transition' do
 
       expect(
-        pt('* * * * * America/Los_Angeles', Time.utc(2015, 3, 8, 10, 00))
-      ).to eq(Time.utc(2015, 3, 8, 9, 59))
+        pt('* * * * * America/Los_Angeles', Time.utc(2015, 3, 8, 10, 00)) \
+          .strftime('%Y-%m-%d %H:%M:%S %Z %z')
+      ).to eq(
+        '2015-03-08 01:59:00 PST -0800'
+      )
     end
 
     it 'correctly decrements every minute through a DST transition' do
@@ -956,7 +1064,7 @@ describe Rufus::Scheduler::CronLine do
         points =
           4.times.collect do
             t = line.previous_time(t)
-            t.to_compact_s
+            t.to_utc_comparison_s
           end
 
         expect(points).to eq([
@@ -980,7 +1088,7 @@ describe Rufus::Scheduler::CronLine do
         points = []
         while t1 - t < 1 * 3600
           t1 = line.next_time(t1)
-          points << t1.to_compact_s
+          points << t1.to_utc_comparison_s
         end
 
         expect(points).to eq(%w[
@@ -1000,8 +1108,11 @@ describe Rufus::Scheduler::CronLine do
     it 'correctly increments through a DST transition' do
 
       expect(
-        nt('* * * * * America/Los_Angeles', Time.utc(2015, 11, 1, 9, 59))
-      ).to eq(Time.utc(2015, 11, 1, 10, 00))
+        nt('* * * * * America/Los_Angeles', Time.utc(2015, 11, 1, 9, 59)) \
+          .strftime('%Y-%m-%d %H:%M:%S %Z %z')
+      ).to eq(
+        '2015-11-01 02:00:00 PST -0800'
+      )
     end
 
     it 'correctly increments every minute through a DST transition' do
@@ -1021,7 +1132,7 @@ describe Rufus::Scheduler::CronLine do
         points =
           4.times.collect do
             t = line.next_time(t)
-            t.to_compact_s
+            t.to_utc_comparison_s
           end
 
         expect(points).to eq([
@@ -1036,8 +1147,11 @@ describe Rufus::Scheduler::CronLine do
     it 'correctly decrements through a DST transition' do
 
       expect(
-        pt('* * * * * America/Los_Angeles', Time.utc(2015, 11, 1, 10, 00))
-      ).to eq(Time.utc(2015, 11, 1, 9, 59))
+        pt('* * * * * America/Los_Angeles', Time.utc(2015, 11, 1, 10, 00)) \
+          .strftime('%Y-%m-%d %H:%M:%S %Z %z')
+      ).to eq(
+        '2015-11-01 01:59:00 PST -0800'
+      )
     end
 
     it 'correctly decrements every minute through a DST transition' do
@@ -1056,7 +1170,7 @@ describe Rufus::Scheduler::CronLine do
         points =
           (0..3).collect do
             t = line.previous_time(t)
-            t.to_compact_s
+            t.to_utc_comparison_s
           end
 
         if t.zone == 'PST'
@@ -1089,7 +1203,7 @@ describe Rufus::Scheduler::CronLine do
         points = []
         while t1 - t < 2 * 3600
           t1 = line.next_time(t1)
-          points << t1.to_compact_s
+          points << t1.to_utc_comparison_s
         end
 
         expect(points).to eq([
