@@ -51,7 +51,28 @@ describe Rufus::Scheduler::AtJob do
 
       job = @scheduler.schedule_at t do; end
 
-      expect(job.time).to eq(t)
+      expect(job.time.to_f).to eq(t.to_f)
+    end
+  end
+
+  describe '#previous_time' do
+
+    it 'returns the previous #time' do
+
+      t = Time.now + 1
+      t0 = nil
+      t1 = nil
+
+      job =
+        @scheduler.schedule_at t do |j|
+          t1 = Time.now
+          t0 = j.previous_time
+        end
+
+      sleep 1.4
+
+      expect(t0.to_f).to eq(t.to_f)
+      expect(t1).to be > t
     end
   end
 end
