@@ -97,7 +97,7 @@ describe Rufus::Scheduler do
 
       sleep 0.4
 
-      expect(t.class).to eq(Time)
+      expect(t.class).to eq(EtOrbi::EoTime)
     end
 
     class MyHandler
@@ -416,7 +416,7 @@ describe Rufus::Scheduler do
           sleep 1
         end
 
-      sleep 0.4
+      sleep 0.49
 
       expect(@scheduler.work_threads(:active).size).to eq(1)
 
@@ -540,7 +540,7 @@ describe Rufus::Scheduler do
         sleep 3
       end
 
-      sleep 0.49
+      sleep 1
 
       expect(@scheduler.running_jobs(:tag => 't0').map(&:original)).to eq(
         %w[ 0.1s ]
@@ -986,7 +986,7 @@ describe Rufus::Scheduler do
 
       sleep 0.7
 
-      expect($tt.class).to eq(Time)
+      expect($tt.class).to eq(EtOrbi::EoTime)
       expect($tt).to be > start
       expect($tt).to be < Time.now
     end
